Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/ARCH/arch-gfortran_osx.fcm
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/ARCH/arch-gfortran_osx.fcm	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/ARCH/arch-gfortran_osx.fcm	(revision 3198)
@@ -15,10 +15,10 @@
 
 
-%NCDF_INC            -I/usr/local/netcdf/include
-%NCDF_LIB            -L/usr/local/netcdf/lib -lnetcdf
-%FC	             gfortran
+%NCDF_INC            -I/usr/local/pub/netcdf/4.0.1-gfortran/include
+%NCDF_LIB            -L/usr/local/pub/netcdf/4.0.1-gfortran/lib -lnetcdf
+%FC	             mpif90
 %FCFLAGS             -fdefault-real-8 -O3 -funroll-all-loops -fcray-pointer 
 %FFLAGS              %FCFLAGS
-%LD                  gfortran
+%LD                  mpif90
 %LDFLAGS
 %FPPFLAGS            -P -C -traditional
Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/ARCH/arch-ifort_osx.fcm
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/ARCH/arch-ifort_osx.fcm	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/ARCH/arch-ifort_osx.fcm	(revision 3198)
@@ -15,6 +15,6 @@
 
 
-%NCDF_INC            -I/usr/local/include 
-%NCDF_LIB            -L /usr/local/lib -lnetcdf   
+%NCDF_INC            -I/usr/local/pub/netcdf/4.0.1-ifort/include 
+%NCDF_LIB            -L /usr/local/pub/netcdf/4.0.1-ifort/lib -lnetcdf   
 %FC                  mpif90
 %FCFLAGS 	     -r8 -O3  -traceback 
Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/CONFIG/makenemo
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/CONFIG/makenemo	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/CONFIG/makenemo	(revision 3198)
@@ -89,5 +89,5 @@
 export TOOLS_DIR=${MAIN_DIR}/TOOLS
 export COMPIL_DIR=${MAIN_DIR}/TOOLS/COMPILE
-export NEMO_DIR=${MAIN_DIR}/NEMO
+export NEMO_DIR=${MAIN_DIR}/${x_s}
 export AGRIFUSE=10
 
@@ -100,4 +100,5 @@
 #- Choice of the options ---
 x_d="";
+x_h="";
 x_n="";
 x_r="";
@@ -106,16 +107,24 @@
 x_c="";
 x_j=1;
-while getopts :hd:n:r:m:j:t: V
+x_e="none";
+x_s=NEMO;
+x_v=1;
+while getopts :hd:n:r:m:j:e:s:v:t: V
 do
     case $V in
-	(h)  echo "Usage	 : "${b_n} \
-	    " [-h] [-n name] [-m arch] [-d "dir1 dir2"] [-r conf] [-j No]";
-	echo " -h	 : help";
-	echo " -n name : config name, [-n help] to list existing configurations";
-	echo " -m arch : choose compiler, [-m help] to list existing compilers";
-	echo " -d dir  : choose NEMO sub-directories";
-	echo " -r conf : choose reference configuration";
-	echo " -j No	 : number of processes used to compile (0=nocompilation)";
-	echo " -t dir  : temporary directory for compilation"
+	(h) x_h=${OPTARG};
+        echo "Usage	 : "${b_n} \
+	    " [-h] [-n name] [-m arch] [-d "dir1 dir2"] [-r conf] [-s Path] [-e Path] [-j No] [-v No]";
+	echo " -h	        : help";
+	echo " -h institute : specific help for consortium members";
+	echo " -n name      : config name, [-n help] to list existing configurations";
+	echo " -m arch      : choose compiler, [-m help] to list existing compilers";
+	echo " -d dir       : choose NEMO sub-directories";
+	echo " -r conf      : choose reference configuration";
+    echo " -s Path      : choose alternative location for NEMO main directory";
+    echo " -e Path      : choose alternative location for MY_SRC directory";
+    echo " -j No        : number of processes used to compile (0=nocompilation)";
+    echo " -v No        : set verbosity level for compilation [0-3]";
+	echo " -t dir       : temporary directory for compilation"
 	echo "";
 	echo "Example to install a new configuration MY_CONFIG";
@@ -137,5 +146,5 @@
 	echo "./makenemo -n MY_CONFIG -j0 add_key \"key_iomput key_mpp_mpi\" del_key \"key_agrif\" ";
 	echo "";
-	. ${COMPIL_DIR}/Flist_archfile.sh  ;
+	. ${COMPIL_DIR}/Flist_archfile.sh ${x_h}  ;
 	echo "";
 	echo "Default : previous configuration and compiler";
@@ -147,4 +156,7 @@
 	(j)  x_j=${OPTARG};;
 	(t)  x_t=${OPTARG};;
+    (e)  x_e=${OPTARG};;
+    (s)  x_s=${OPTARG};;
+    (v)  x_v=${OPTARG};;
 	(:)  echo ${b_n}" : -"${OPTARG}" option : missing value" 1>&2;
 	exit 2;;
@@ -205,5 +217,5 @@
     exit
 fi
-[ "${CMP_NAM}" ==  help ] && . ${COMPIL_DIR}/Flist_archfile.sh && exit
+[ "${CMP_NAM}" ==  help ] && . ${COMPIL_DIR}/Flist_archfile.sh all && exit
 
 #- When used for the first time, choose a compiler ---
@@ -250,5 +262,5 @@
 #- Clean links and librairies ---
 #- Creating the good links, at first on OPA_SRC ---
-. ${COMPIL_DIR}/Fmake_WORK.sh ${NEW_CONF} ${TAB[*]} || exit
+. ${COMPIL_DIR}/Fmake_WORK.sh ${x_e} ${NEW_CONF} ${TAB[*]} || exit
 
 . ${COMPIL_DIR}/Fmake_bld.sh ${CONFIG_DIR} ${NEW_CONF}  ${NEMO_TDIR} || exit
@@ -290,5 +302,5 @@
         [ "$AGRIFUSE" == 1 ] && rm -rf  ${NEMO_TDIR}/${NEW_CONF}/BLD/*
     fi
-    fcm build ${x_c} --ignore-lock -v 1 -j ${NBR_PRC} ${COMPIL_DIR}/$USEBLD || cd -
+    fcm build ${x_c} --ignore-lock -v ${x_v} -j ${NBR_PRC} ${COMPIL_DIR}/$USEBLD || cd -
     [ -f ${NEMO_TDIR}/${NEW_CONF}/BLD/bin/nemo.exe ] && ln -sf ${NEMO_TDIR}/${NEW_CONF}/BLD/bin/nemo.exe  ${CONFIG_DIR}/${NEW_CONF}/EXP00/opa
     [ -f ${NEMO_TDIR}/${NEW_CONF}/BLD/bin/server.exe ] && ln -sf ${NEMO_TDIR}/${NEW_CONF}/BLD/bin/server.exe  ${CONFIG_DIR}/${NEW_CONF}/EXP00/server.exe
Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcheck_archfile.sh
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcheck_archfile.sh	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcheck_archfile.sh	(revision 3198)
@@ -69,4 +69,8 @@
    fi
 else
-   ln -sf ${MAIN_DIR}/ARCH/arch-${2}.fcm ${COMPIL_DIR}/$1
+   if [ -f  ${MAIN_DIR}/ARCH/arch-${2}.fcm ]; then
+      ln -sf ${MAIN_DIR}/ARCH/arch-${2}.fcm ${COMPIL_DIR}/$1
+   else
+      ln -sf ${MAIN_DIR}/ARCH/LOCAL/arch-${2}.fcm ${COMPIL_DIR}/$1
+   fi   
 fi
Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fclean_config.sh
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fclean_config.sh	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fclean_config.sh	(revision 3198)
@@ -69,5 +69,5 @@
  if [  -z "$answer" -o "x$answer" = "xy" ]; then
  	# testing if configuration exists
- 	if [ "$(cat ${COMPIL_DIR}/cfg.txt | grep "${NEW_CONF} ")"  == "" ] ; then
+ 	if [ "$(cat ${CONFIG_DIR}/cfg.txt | grep "${NEW_CONF} ")"  == "" ] ; then
 		echo "The configuration ${NEW_CONF} does not exist in file cfg.txt"     
 		echo "No removing configuration"
@@ -75,6 +75,6 @@
         else
 		rm -rf ${CONFIG_DIR}/${NEW_CONF}
-		sed -e "/${NEW_CONF} /d"  ${COMPIL_DIR}/cfg.txt >  ${COMPIL_DIR}/cfg.tmp
-		mv  ${COMPIL_DIR}/cfg.tmp  ${COMPIL_DIR}/cfg.txt
+		sed -e "/${NEW_CONF} /d"  ${CONFIG_DIR}/cfg.txt >  ${CONFIG_DIR}/cfg.tmp
+		mv  ${CONFIG_DIR}/cfg.tmp  ${CONFIG_DIR}/cfg.txt
 		echo "${NEW_CONF} configuration REMOVED" 
         fi
Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcopy_dir.sh
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcopy_dir.sh	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcopy_dir.sh	(revision 3198)
@@ -55,8 +55,8 @@
 
 declare -a ZTAB
-grep "$1 " ${COMPIL_DIR}/cfg.txt > ${COMPIL_DIR}/cfg.tmp
-read -a ZTAB < ${COMPIL_DIR}/cfg.tmp
+grep "$1 " ${CONFIG_DIR}/cfg.txt > ${CONFIG_DIR}/cfg.tmp
+read -a ZTAB < ${CONFIG_DIR}/cfg.tmp
 TAB=( ${ZTAB[@]:1} )
-\rm ${COMPIL_DIR}/cfg.tmp
+\rm ${CONFIG_DIR}/cfg.tmp
 
 unset -v ZTAB
Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Flist_archfile.sh
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Flist_archfile.sh	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Flist_archfile.sh	(revision 3198)
@@ -19,5 +19,5 @@
 # ::
 #
-#  $ Flist_archfile.sh
+#  $ Flist_archfile.sh Institute
 #
 #
@@ -37,4 +37,5 @@
 #  $ ./Flist_archfile.sh 
 #
+#  $ ./Flist_archfile.sh CNRS
 #
 # TODO
@@ -54,6 +55,11 @@
 #
 #-
+
+if [ -n "$2" ]; then
+shift
+fi
+
 echo "Available compilers for -m option :"
-for file in `ls ${MAIN_DIR}/ARCH`
+for file in  $(ls ${MAIN_DIR}/ARCH | grep fcm )
 do
 zvar1=${file#arch-}
@@ -62,2 +68,28 @@
 printf "%-20s %s %-s\n" "${zvar1%.fcm}" : "${zvar2#\#}"
 done
+
+
+if [ "$1" == "all" ]; then
+   for dir  in  $(ls ${MAIN_DIR}/ARCH | grep -v fcm )
+   do 
+      echo "Available compilers at ${dir} :"
+      for file in  $(ls ${MAIN_DIR}/ARCH/${dir} | grep  fcm )
+      do
+      zvar1=${file#arch-}
+      zvar2=$(head -1 ${MAIN_DIR}/ARCH/${dir}/$file)
+      #echo "${zvar1%.fcm} : ${zvar2#\#}"
+      printf "%-20s %s %-s\n" "${zvar1%.fcm}" : "${zvar2#\#}"
+      done
+   done
+else
+   if [ -d ${MAIN_DIR}/ARCH/${1} ]; then
+      echo "Available compilers at $1 :"
+      for file in  $(ls ${MAIN_DIR}/ARCH/$1 | grep fcm )
+      do
+      zvar1=${file#arch-}
+      zvar2=$(head -1 ${MAIN_DIR}/ARCH/${1}/$file)
+      #echo "${zvar1%.fcm} : ${zvar2#\#}"
+      printf "%-20s %s %-s\n" "${zvar1%.fcm}" : "${zvar2#\#}"
+      done
+   fi
+fi
Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fmake_WORK.sh
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fmake_WORK.sh	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fmake_WORK.sh	(revision 3198)
@@ -64,13 +64,24 @@
 #
 #-
-declare ZCONF=$1 ; shift 
+declare ZSRC=$1 ; shift 
+declare ZCONF=$1 ; shift
 ZTAB=( $@ )
 declare i=0 ; declare NDIR=${#ZTAB[@]}
 
 echo "Creating ${ZCONF}/WORK = ${ZTAB[*]} for ${ZCONF}"
-echo ""
 
 [ ! -d ${ZCONF}/MY_SRC ] && \mkdir ${ZCONF}/MY_SRC
 [   -d ${ZCONF}/WORK   ] || \mkdir ${ZCONF}/WORK
+
+if [ "${ZSRC}" != "none" ] ; then 
+  if [ -d ${ZSRC} ] ; then 
+     ln -sf ${ZSRC}/*.[Ffh]90 ${ZCONF}/MY_SRC/. 
+     echo "MY_SRC content is linked to ${ZSRC}" 
+  else
+     echo "External directory for MY_SRC does not exist. Using default."
+  fi
+else 
+echo "MY_SRC directory is : ${ZCONF}/MY_SRC"
+fi
 
 \rm -f ../${1}/WORK/*

Index: branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcheck_config.sh
===================================================================
--- branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcheck_config.sh	(revision 3196)
+++ branches/2011/dev_NEMO_MERGE_2011/NEMOGCM/TOOLS/COMPILE/Fcheck_config.sh	(revision 3198)
@@ -39,5 +39,5 @@
 # - Nothing set, use the previous in use 
 #
 # We use TOOLS/COMPILE/cfg.txt to check if the onfiguration exists.
 #
 # EXAMPLES
@@ -68,8 +68,8 @@
 declare -a ZTAB
 if [ ${#2} -eq 0 ]; then
-   tail -1  ${COMPIL_DIR}/$1	> ${COMPIL_DIR}/cfg.tmp
-   read -a ZTAB < ${COMPIL_DIR}/cfg.tmp
+   tail -1  ${CONFIG_DIR}/$1	> ${CONFIG_DIR}/cfg.tmp
+   read -a ZTAB < ${CONFIG_DIR}/cfg.tmp
    NEW_CONF=${ZTAB[0]} ; TAB=( ${ZTAB[@]:1} )
-   \rm ${COMPIL_DIR}/cfg.tmp
+   \rm ${CONFIG_DIR}/cfg.tmp
    echo "Warning !!!"
    echo "No configuration specified"
@@ -79,8 +79,8 @@
 fi
 if [ "$1" == cfg.txt ]; then
-   cat ${COMPIL_DIR}/$1 | grep "${NEW_CONF} " > ${COMPIL_DIR}/cfg.tmp
-   read -a ZTAB < ${COMPIL_DIR}/cfg.tmp
+   cat ${CONFIG_DIR}/$1 | grep "${NEW_CONF} " > ${CONFIG_DIR}/cfg.tmp
+   read -a ZTAB < ${CONFIG_DIR}/cfg.tmp
    NEW_CONF=${ZTAB[0]} ; TAB=( ${ZTAB[@]:1} )
-   \rm ${COMPIL_DIR}/cfg.tmp
+   \rm ${CONFIG_DIR}/cfg.tmp
 fi
 
@@ -39,5 +39,5 @@
 # - Nothing set, use the previous in use 
 #
-# We use TOOLS/COMPILE/cfg.txt to check if the onfiguration exists.
+# We use TOOLS/CONFIG_DIR/cfg.txt to check if the onfiguration exists.
 #
 # EXAMPLES